@@ -244,7 +244,7 @@ myBiomodData <- BIOMOD_FormatingData( resp.var = as.numeric(sp_occ[,sp]),
                                       resp.xy = xy,
                                       resp.name = colnames(sp_occ)[sp])
 
-myBiomodOption <- Print_Default_ModelingOptions()
+myBiomodOption <- bm_DefaultModelingOptions()
 myBiomodOption@GLM$test = 'none'
 myBiomodOption@GBM$interaction.depth = 2
 
